Gradient scale Map a numeric vector to a color gradient
color.gradient.RdGradient scale Map a numeric vector to a color gradient
Usage
color.gradient(x, colors = c("red", "yellow", "green"), colsteps = 100)color.gradient.RdGradient scale Map a numeric vector to a color gradient
color.gradient(x, colors = c("red", "yellow", "green"), colsteps = 100)