extract_dates_from_tiff_files.Rd
Extract acquisition dates from a set of TIFF file names
extract_dates_from_tiff_files(tiff_files)
character vector. File paths or names containing a date in either YYYY-MM-DD or YYYYMMDD format, which will be extracted via regular expression.
YYYY-MM-DD
YYYYMMDD
dates