PRISMA hyperspectral sensor band FWHM table
fwhm.prisma.RdPer-channel centre wavelength and full-width-half-maximum (FWHM) table for the PRISMA hyperspectral imager, used to build a Gaussian spectral response for PRISMA bands.
fwhm.prisma.RdPer-channel centre wavelength and full-width-half-maximum (FWHM) table for the PRISMA hyperspectral imager, used to build a Gaussian spectral response for PRISMA bands.