extract spectral indices at Sentinel-2 resolution
getIndicesSE2.Rdextract spectral indices at Sentinel-2 resolution
Arguments
- df
a dataframe with reflectance where each rows correspond with an spectrum
- sensor
Sensor options: 'Sentinel-2a', or 'Sentinel-2b'
- df.data
dataset with IDs that corresponde with each spectrum, is null is also enable
- fast.process
when the bands are ordered for SE2, please use fast.process = T, otherwise use False or nothing