Reverse a caret preProcess transformation and round the result
getReverse.trans.RdReverse a caret preProcess transformation and round the result
Arguments
- preProc
a "preProcess" object created by
caret::preProcess(), describing the transformation to reverse.- data
a matrix. Transformed data to convert back to its original scale.
- digits
integer. Number of decimal places to round the reversed values to. Default 10.