Skip to contents

A single example leaf optical spectrum bundled for demonstrating spectral plotting and convolution functions in the package vignettes.

Usage

leaf_spectrum

Format

A data frame with 2100 rows (one per 1 nm wavelength band, 400-2500 nm) and 3 columns holding wavelength and paired reflectance/transmittance-like values.