Generate a single variable from a distribution correlated with another distribution
rnormcor.RdAllow user to draw from a random normal distribution correlated with a user specified distribution
rnormcor.RdAllow user to draw from a random normal distribution correlated with a user specified distribution