PRISMA measured spectral response functions
srf.prisma.RdFull measured per-band spectral response function (SRF) curves for the PRISMA hyperspectral imager, sampled on a common wavelength grid.
srf.prisma.RdFull measured per-band spectral response function (SRF) curves for the PRISMA hyperspectral imager, sampled on a common wavelength grid.