Get the packages
get.packages.RdThis function retrieves the list of R package dependencies for the specified path
using renv::dependencies(). If renv is not installed, it installs renv first. THis is designed for getting the packages
that the Shiny app needs in this package
Arguments
- path
The directory path to check for dependencies. Defaults to the current directory.
- confirm
logical. If
TRUE(the default) and the session is interactive, ask for confirmation before installing renv or any missing dependency. IfFALSE, never install anything; missing packages are only reported, not installed. Per CRAN policy, this function never installs packages in a non-interactive session regardless ofconfirm.