Example measured leaf reflectance/transmittance spectrum
leaf_spectrum.RdA single example leaf optical spectrum bundled for demonstrating spectral plotting and convolution functions in the package vignettes.
leaf_spectrum.RdA single example leaf optical spectrum bundled for demonstrating spectral plotting and convolution functions in the package vignettes.