Generate a vector from a binomial distribution correlated with another distribution
rbinomcor.RdAllow user to draw from a binomial distribution correlated with a user specified vector
rbinomcor.RdAllow user to draw from a binomial distribution correlated with a user specified vector