Generate a vector from a negative binomial distribution correlated with another distribution
rnegbinomcor.RdAllow user to draw from a negative binomial distribution correlated with a user specified vector
rnegbinomcor.RdAllow user to draw from a negative binomial distribution correlated with a user specified vector