Generate a vector from a normal distribution correlated with another distribution
rnormcorV.RdAllow user to draw from a random normal distribution correlated with a user specified vector
rnormcorV.RdAllow user to draw from a random normal distribution correlated with a user specified vector